// Client.cpp : Defines the entry point for the console application.
//

#include "stdafx.h"
#include <Ice/Ice.h>
#include <Filesystem.h>
#include <iostream>
#include <iterator>
#include <limits>

using namespace std;
using namespace Filesystem;

//===============================================================
// Recursively print the contents of directory "dir" in
// tree fashion. For files, show the contents of each file.
// The "depth" parameter is the current nesting level
// (for indentation).
static void listRecursive(const DirectoryPrx& dir, int depth = 0)
{
	string indent(++depth, '\t');
	NodeSeq contents = dir->list();
	for (NodeSeq::const_iterator i = contents.begin(); i != contents.end(); ++i) {
		DirectoryPrx dir = DirectoryPrx::checkedCast(*i);
		FilePrx file = FilePrx::uncheckedCast(*i);
		cout << indent << (*i)->name() << (dir ? " (directory):" : " (file):") << endl;
		if(dir) {
			listRecursive(dir, depth);
		} else {
			Lines text = file->read();
			for(Lines::const_iterator j = text.begin(); j != text.end(); ++j) {
				cout << (std::string)indent << "\t" << *j << endl;
			}
		}
	}
}

//===============================================================
int main(int argc, char* argv[])
{
	int status = 0;
	Ice::CommunicatorPtr ic;
	try {
		// Create a communicator
		ic = Ice::initialize(argc, argv);

		// Create a proxy for the root directory
		cout << "Getting Node proxy for root dir on localhost, tcp, port 10000" << endl;
		Ice::ObjectPrx base = ic->stringToProxy("RootDir:tcp -h localhost -p 10000 -t 200");
		if(!base)
			throw "Could not create proxy";

		// Downcast the proxy to a Directory proxy
		DirectoryPrx rootDir = DirectoryPrx::checkedCast(base);
		if(!rootDir)
			throw "Invalid proxy";

		// Recursively list the contents of the root directory
		cout << "Contents of the root directory:" << endl;
		listRecursive(rootDir);
	} catch (const Ice::Exception& ex) {
		cerr << ex << endl;
		status = 1;
	} catch (const char* msg) {
		cerr << msg << endl;
		status = 1;
	}

	// cleanup
	if(ic)
		ic->destroy();

	cout << "Press enter to exit...";
	cin.ignore(numeric_limits<std::streamsize>::max(), '\n');
	return status;
}

